.. image:: https://img.shields.io/pypi/v/Tent.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/Tent/
.. image:: https://github.com/Clivern/Tent/actions/workflows/ci.yml/badge.svg
    :alt: Build Status
    :target: https://github.com/Clivern/Tent/actions/workflows/ci.yml

|

====
Tent
====

    Github Automation Package in Python.
